Contributing
============

We welcome all contributions.

To report any bugs or file feature requests, please use the `issue
tracker`_. Otherwise
feel free to fork the repository, make your own changes and send a pull
request.


.. _issue tracker: https://github.com/aboucaud/pypher/issues
